==> heaserver_keychain-1.2.0.tar.gz: heaserver_keychain-1.2.0/integrationtests/heaserver/keychainintegrationtest/testcase.py <==
"""
Creates a test case class for use with the unittest library that is built into Python.
"""

from heaserver.service.testcase.microservicetestcase import get_test_case_cls_default
from heaserver.service.testcase.dockermongo import MockDockerMongoManager
from heaserver.keychain import service
from heaobject.user import NONE_USER
from heaserver.service.testcase.expectedvalues import Action

db_store = {
    service.MONGODB_CREDENTIALS_COLLECTION: [{
        'id': '666f6f2d6261722d71757578',
        'created': None,
        'derived_by': None,
        'derived_from': [],
        'description': None,
        'display_name': 'Reximus',
        'invites': [],
        'modified': None,
        'name': 'reximus',
        'owner': NONE_USER,
        'shares': [],
        'source': None,
        'source_detail': None,
        'type': 'heaobject.keychain.Credentials',
        'created': None,
        'account': None,
        'where': None,
        'password': None,
        'type_display_name': 'Credentials'
    },
        {
            'id': '0123456789ab0123456789ab',
            'created': None,
            'derived_by': None,
            'derived_from': [],
            'description': None,
            'display_name': 'Luximus',
            'invites': [],
            'modified': None,
            'name': 'luximus',
            'owner': NONE_USER,
            'shares': [],
            'source': None,
            'source_detail': None,
            'type': 'heaobject.keychain.Credentials',
            'created': None,
            'account': None,
            'where': None,
            'password': None,
            'type_display_name': 'Credentials'
        }]}

TestCase = get_test_case_cls_default(coll=service.MONGODB_CREDENTIALS_COLLECTION,
                                     href='http://localhost:8080/credentials',
                                     wstl_package=service.__package__,
                                     db_manager_cls=MockDockerMongoManager,
                                     fixtures=db_store,
                                     get_actions=[Action(name='heaserver-keychain-credentials-get-properties',
                                                         rel=['hea-context-menu', 'hea-properties'],
                                                         itemif='type=="heaobject.keychain.Credentials"'),
                                                  Action(name='heaserver-keychain-awscredentials-get-properties',
                                                         rel=['hea-context-menu', 'hea-properties'],
                                                         itemif='type=="heaobject.keychain.AWSCredentials"'),
                                                  # Action(name='heaserver-keychain-credentials-open-choices',
                                                  #        url='http://localhost:8080/credentials/{id}/opener',
                                                  #        rel=['hea-context-menu', 'hea-opener-choices']),
                                                  # Action(name='heaserver-keychain-credentials-duplicate',
                                                  #        url='http://localhost:8080/credentials/{id}/duplicator',
                                                  #        rel=['hea-context-menu', 'hea-dynamic-standard', 'hea-icon-duplicator']),
                                                  Action(name='heaserver-keychain-credentials-get-self',
                                                             url='http://localhost:8080/credentials/{id}',
                                                             rel=['self']),
                                                  Action(name='heaserver-keychain-awscredentials-get-cli-credentials-file',
                                                             url='http://localhost:8080/credentials/{id}/awsclicredentialsfile',
                                                             rel=['hea-dynamic-clipboard', 'hea-icon-for-clipboard', 'hea-context-menu'],
                                                             itemif='type=="heaobject.keychain.AWSCredentials"')
                                                  ],
                                     get_all_actions=[Action(name='heaserver-keychain-credentials-get-properties',
                                                             rel=['hea-context-menu', 'hea-properties'],
                                                             itemif='type=="heaobject.keychain.Credentials"'),
                                                      Action(name='heaserver-keychain-awscredentials-get-properties',
                                                             rel=['hea-context-menu', 'hea-properties'],
                                                             itemif='type=="heaobject.keychain.AWSCredentials"'),
                                                      # Action(name='heaserver-keychain-credentials-open-choices',
                                                      #        url='http://localhost:8080/credentials/{id}/opener',
                                                      #        rel=['hea-context-menu', 'hea-opener-choices']),
                                                      # Action(name='heaserver-keychain-credentials-duplicate',
                                                      #        url='http://localhost:8080/credentials/{id}/duplicator',
                                                      #        rel=['hea-context-menu', 'hea-dynamic-standard', 'hea-icon-duplicator']),
                                                      Action(name='heaserver-keychain-credentials-get-self',
                                                             url='http://localhost:8080/credentials/{id}',
                                                             rel=['self']),
                                                      Action(name='heaserver-keychain-awscredentials-get-cli-credentials-file',
                                                             url='http://localhost:8080/credentials/{id}/awsclicredentialsfile',
                                                             rel=['hea-dynamic-clipboard', 'hea-icon-for-clipboard', 'hea-context-menu'],
                                                             itemif='type=="heaobject.keychain.AWSCredentials"')],
                                     #duplicate_action_name='heaserver-keychain-credentials-duplicate-form'
                                     )

==> heaserver_keychain-1.3.0.tar.gz: heaserver_keychain-1.3.0/integrationtests/heaserver/keychainintegrationtest/testcase.py <==
"""
Creates a test case class for use with the unittest library that is built into Python.
"""

from heaserver.service.testcase.microservicetestcase import get_test_case_cls_default
from heaserver.service.testcase.dockermongo import MockDockerMongoManager
from heaserver.keychain import service
from heaobject.user import NONE_USER
from heaserver.service.testcase.expectedvalues import Action

db_store = {
    service.MONGODB_CREDENTIALS_COLLECTION: [{
        'id': '666f6f2d6261722d71757578',
        'created': '2022-05-17T00:00:00+00:00',
        'derived_by': None,
        'derived_from': [],
        'description': None,
        'display_name': 'Reximus',
        'invites': [],
        'modified': '2022-05-17T00:00:00+00:00',
        'name': 'reximus',
        'owner': NONE_USER,
        'shares': [],
        'source': None,
        'source_detail': None,
        'type': 'heaobject.keychain.Credentials',
        'account': None,
        'where': None,
        'password': None,
        'type_display_name': 'Credentials',
        'role': None
    },
        {
            'id': '0123456789ab0123456789ab',
            'created': '2022-05-17T00:00:00+00:00',
            'derived_by': None,
            'derived_from': [],
            'description': None,
            'display_name': 'Luximus',
            'invites': [],
            'modified': '2022-05-17T00:00:00+00:00',
            'name': 'luximus',
            'owner': NONE_USER,
            'shares': [],
            'source': None,
            'source_detail': None,
            'type': 'heaobject.keychain.Credentials',
            'account': None,
            'where': None,
            'password': None,
            'type_display_name': 'Credentials',
            'role': None
        }]}

TestCase = get_test_case_cls_default(coll=service.MONGODB_CREDENTIALS_COLLECTION,
                                     href='http://localhost:8080/credentials',
                                     wstl_package=service.__package__,
                                     db_manager_cls=MockDockerMongoManager,
                                     fixtures=db_store,
                                     get_actions=[Action(name='heaserver-keychain-credentials-get-properties',
                                                         rel=['hea-context-menu', 'hea-properties'],
                                                         itemif='type=="heaobject.keychain.Credentials"'),
                                                  Action(name='heaserver-keychain-awscredentials-get-properties',
                                                         rel=['hea-context-menu', 'hea-properties'],
                                                         itemif='type=="heaobject.keychain.AWSCredentials"'),
                                                  # Action(name='heaserver-keychain-credentials-open-choices',
                                                  #        url='http://localhost:8080/credentials/{id}/opener',
                                                  #        rel=['hea-context-menu', 'hea-opener-choices']),
                                                  # Action(name='heaserver-keychain-credentials-duplicate',
                                                  #        url='http://localhost:8080/credentials/{id}/duplicator',
                                                  #        rel=['hea-context-menu', 'hea-dynamic-standard', 'hea-icon-duplicator']),
                                                  Action(name='heaserver-keychain-credentials-get-self',
                                                             url='http://localhost:8080/credentials/{id}',
                                                             rel=['self']),
                                                  Action(name='heaserver-keychain-awscredentials-get-cli-credentials-file',
                                                             url='http://localhost:8080/credentials/{id}/awsclicredentialsfile',
                                                             rel=['hea-dynamic-clipboard', 'hea-icon-for-clipboard', 'hea-context-menu'],
                                                             itemif='type=="heaobject.keychain.AWSCredentials"')
                                                  ],
                                     get_all_actions=[Action(name='heaserver-keychain-credentials-get-properties',
                                                             rel=['hea-context-menu', 'hea-properties'],
                                                             itemif='type=="heaobject.keychain.Credentials"'),
                                                      Action(name='heaserver-keychain-awscredentials-get-properties',
                                                             rel=['hea-context-menu', 'hea-properties'],
                                                             itemif='type=="heaobject.keychain.AWSCredentials"'),
                                                      # Action(name='heaserver-keychain-credentials-open-choices',
                                                      #        url='http://localhost:8080/credentials/{id}/opener',
                                                      #        rel=['hea-context-menu', 'hea-opener-choices']),
                                                      # Action(name='heaserver-keychain-credentials-duplicate',
                                                      #        url='http://localhost:8080/credentials/{id}/duplicator',
                                                      #        rel=['hea-context-menu', 'hea-dynamic-standard', 'hea-icon-duplicator']),
                                                      Action(name='heaserver-keychain-credentials-get-self',
                                                             url='http://localhost:8080/credentials/{id}',
                                                             rel=['self']),
                                                      Action(name='heaserver-keychain-awscredentials-get-cli-credentials-file',
                                                             url='http://localhost:8080/credentials/{id}/awsclicredentialsfile',
                                                             rel=['hea-dynamic-clipboard', 'hea-icon-for-clipboard', 'hea-context-menu'],
                                                             itemif='type=="heaobject.keychain.AWSCredentials"')],
                                     #duplicate_action_name='heaserver-keychain-credentials-duplicate-form'
                                     )
